August 20th, 2017
=================

```
Venue : SPACE, Vellayambalam
Time  : 2:00 PM - 6:30 PM
```

## Members Present
- Ashish Kurian Thomas
- Aswin Babu Karuvally
- Athul R T
- Gokul Das B
- Madhav V
- Pranav V
- Sachin Gracious
- Tanzeem Mohammed Basheer

## General Decisions
- FSUG-TVM development group migrated to git.fosscommunity.in from gitlab.com
- Tool study should be accompanied by development (Ashish)
    - We aim to be full free software community with promotion, familiarization 
    and development
- Form a developer's communication channel (Ashish)
- Arrange a session for shell operations (Aswin)
- Do publicity campaigns, especially in colleges to attract more members
(Madhav)

## Next Meeting
```
Date   : August 27th, 2017
Time   : 2:00 PM to 6:00 PM
Venue  : SPACE, Vellayambalam
Topics :
    1. Shell Commands & Scripting (Ashish Kurian Thomas)
```

## Technical Session (Intermediate Git)
Introduction to git was continued today with emphasis on internal data
representation inside the repository. The session was taken by Gokul Das
@gokuldas.

### Concepts
**Working Tree:** The working tree is the tree of source code where the
developer modifies code.

**Repository:** The directory inside which the snapshots of development and
other metadata are stored. It is usually a `.git` folder inside the working
tree.

Initializing a repository:
```shell
git init [name_of_working_tree]
```

**Blobs:** Source files stored inside repository with they sha1 hash as
filename.

**Tree Object:** Directories containing information about files. Stored like
blobs with sha1 hash as filename.

**Commit Object:** Contains information about commit. Holds commit message,
author, date and time, root tree object of the snapshot and pointer to parent
commit object/s. Stored again with sha1 hash as filename. Commit objects form
directed acyclic graph that records the evolution of source tree.

**Index/Stage:** The tree object that represents the change to be committed.
Working tree files are explicitly added using `git add filename` command to the
index. Every commit saves a snapshot of the index.

**References:** Pointers pointing to different commit objects. There are 3
types of references: **branches**, **tags** and **HEAD**.

**Branch:** A reference that tracks the progress of the working tree. The repo
tracks one branch at a time. The current branch is updated to the latest commit
everytime. Checking out a branch modifies the working tree to be the same as
the commit that the branch is pointing to.

List all branches:
```shell
git branch -v
```

Make a new branch at HEAD:
```shell
git branch branchname
```

Delete a branch:
```shell
git branch -d branchname
```

Checkout a branch (Make working tree same as branch commit, follow the branch):
```shell
git checkout branchname
```

**HEAD:** Tracks the latest commit from the working tree. Usually points to the
current branch.

**Remotes:** Pointers to other copies of the same repository. When you clone
from a repo, that repo is added by default as 'origin' remote.

List all remotes:
```shell
git remote -v
```

Show details of remote:
```shell
git remote show remotename
```

Add a remote:
```shell
git remote add remotename url_to_remote
```

Remove a remote:
```shell
git remote remove remotename
```

**Remote tracking branches:** Branches named in the format 'remote/branch'
(like origin/master), that points to the state of branches in that remote. You
cannot commit to these branches. These branches are automatically updated
during fetches, pulls and merges.

List all branches (including remote tracking ones):
```shell
git branch -va
```

Make a local branch from a remote branch:
```shell
git checkout -b branchname remotename/branch
```

**Branching:** Creating a new branch at current HEAD position. After checkout
of that branch, all new commits will proceed to the new branch.

**Merging:** Combining 2 different branches into one. You may have to resolve
conflicts manually if automatic merging algorithm can't decide what to do.

Merge branchA to branchB (an automatic merge commit will happen):
```shell
git checkout branchB
git merge branchA
```

Steps to do after resolving a merge conflict (commit will be merge commit):
```shell
git add filename
git commit
```

**Push:** Sending changes of local repo to remote. Only one branch is pushed at
a time.

Push mybranch to origin (with an optional new name):
```shell
git push origin mybranch[:newname]
```

Delete a remote branch:
```shell
git push -d orgin mybranch
```

Push branch to remote; set remote as push/fetch target for the branch:
```shell
git push -u remotename branchname
```

**Fetch:** Bringing commits from remote to local remote tracking branches. All
remote branches are fected at once.
```shell
git fetch [remotename]
```

**Pull:** A fetch followed by a merge from the upstream remote tracking branch
to the current branch.
```shell
git pull [remotename]
```

Prepared by: Gokul Das B @gokuldas
